# KAITO

[KAITO](https://kaito-project.github.io/kaito/docs/) is a Kubernetes operator that supports deploying and serving LLMs with vLLM. It offers managing large models via container images with built-in OpenAI-compatible inference, auto-provisioning GPU nodes and curated model presets.

Please refer to [quick start](https://kaito-project.github.io/kaito/docs/quick-start) for more details.
